<?php
// Start the session
session_start();

// Redirect to login page if not logged in
if (!isset($_SESSION['logged_in']) || $_SESSION['logged_in'] !== true) {
    header('Location: login.php'); // Redirect to login.php if not logged in
    exit;
}

// Define the base directory where logo posts are stored
$baseDir = $_SERVER['DOCUMENT_ROOT'] . '/logos'; // Adjust this path if needed

// Initialize message variables
$uploadMessage = '';
$errorMessage = '';

// Get the slug (post name) passed via GET
if (isset($_GET['edit'])) {
    $slug = $_GET['edit']; 
    $postDir = $baseDir . '/' . $slug;

    // Check if the post directory exists
    if (!is_dir($postDir)) {
        $errorMessage = "Post '$slug' not found.";
    }

    // Get all files in the post folder
    $files = array_diff(scandir($postDir), array('.', '..'));

    // Handle file deletion
    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['delete_file'])) {
        $fileName = $_POST['file_name'];
        $filePath = $postDir . '/' . $fileName;
        
        if (file_exists($filePath)) {
            unlink($filePath); // Delete the file
            $uploadMessage = "File '$fileName' has been deleted.";
            $files = array_diff(scandir($postDir), array('.', '..')); // Refresh the file list
        } else {
            $errorMessage = "Error: File '$fileName' not found.";
        }
    }

    // Handle post deletion
    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['delete_post'])) {
        // Delete all files in the post folder and remove the folder itself
        foreach ($files as $file) {
            unlink($postDir . '/' . $file);
        }
        rmdir($postDir);
        $uploadMessage = "The post '$slug' and all its files have been deleted.";
        exit; // Exit after deletion
    }

    // Handle file upload
    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_FILES['file_upload'])) {
        $uploadFile = $_FILES['file_upload'];
        $uploadDir = $postDir . '/'; // Upload to the post's directory

        // Validate file upload
        $maxFileSize = 5 * 1024 * 1024; // Max file size (5MB)
        $allowedTypes = ['image/jpeg', 'image/png', 'image/gif', 'application/pdf', 'application/zip']; // Allowed mime types

        if ($uploadFile['error'] === UPLOAD_ERR_OK) {
            $fileTmpPath = $uploadFile['tmp_name'];
            $fileName = basename($uploadFile['name']);
            $filePath = $uploadDir . $fileName;

            // Check file size and type
            $fileExtension = strtolower(pathinfo($fileName, PATHINFO_EXTENSION));

            // Add ZIP file extension check in addition to MIME type check
            if ($uploadFile['size'] > $maxFileSize) {
                $errorMessage = "Error: File is too large. Maximum file size is 5MB.";
            } elseif (!in_array($uploadFile['type'], $allowedTypes) && $fileExtension !== 'zip') {
                $errorMessage = "Error: Invalid file type. Only JPEG, PNG, GIF, PDF, and ZIP are allowed.";
            } elseif (move_uploaded_file($fileTmpPath, $filePath)) {
                // Success message
                $uploadMessage = "File '$fileName' has been uploaded successfully.";
                $files = array_diff(scandir($postDir), array('.', '..')); // Refresh the file list
            } else {
                $errorMessage = "Error: File upload failed.";
            }
        } else {
            $errorMessage = "Error: " . $uploadFile['error'];
        }
    }
}

// Function to get the file icon based on the file extension
function getFileIcon($fileName) {
    $extension = pathinfo($fileName, PATHINFO_EXTENSION);
    
    switch (strtolower($extension)) {
        case 'png':
            return '<img src="/assets/png.svg" alt="PNG Icon" width="40" height="40">';
        case 'svg':
            return '<img src="/assets/svg.svg" alt="SVG Icon" width="40" height="40">';
        case 'ai':
            return '<img src="/assets/ai.svg" alt="AI Icon" width="40" height="40">';
        case 'zip':
            return '<img src="/assets/zip.svg" alt="ZIP Icon" width="40" height="40">'; // Add ZIP icon
        default:
            return ''; // No icon for unsupported file types
    }
}
?>

<!DOCTYPE html>
<html lang="en">
    <?php include 'header.php'; ?>

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Post - <?php echo htmlspecialchars($slug, ENT_QUOTES, 'UTF-8'); ?></title>
    <link rel="stylesheet" href="styles.css">
</head>
<body>

    <div class="container">
        <h1>Edit Post: <?php echo htmlspecialchars($slug, ENT_QUOTES, 'UTF-8'); ?></h1>

        <!-- Delete Entire Post Form -->
        <form action="edit.php?edit=<?php echo urlencode($slug); ?>" method="POST" onsubmit="return confirm('Are you sure you want to delete this post and all its files?');">
            <button type="submit" name="delete_post" class="delete-button">Delete Entire Post</button>
        </form>

        <!-- Upload File Form -->
        <h2>Upload New File</h2>
        <form action="edit.php?edit=<?php echo urlencode($slug); ?>" method="POST" enctype="multipart/form-data" class="upload-form">
            <input type="file" name="file_upload" class="upload-input" required>
            <button type="submit" class="upload-button">Upload File</button>
        </form>

        <!-- Success Message (If File Upload is Successful) -->
        <?php if ($uploadMessage): ?>
            <div class="message success"><?php echo htmlspecialchars($uploadMessage, ENT_QUOTES, 'UTF-8'); ?></div>
        <?php endif; ?>

        <!-- Error Message (If There Are Errors) -->
        <?php if ($errorMessage): ?>
            <div class="message error"><?php echo htmlspecialchars($errorMessage, ENT_QUOTES, 'UTF-8'); ?></div>
        <?php endif; ?>

        <h2>Files in Post</h2>
        <table>
            <thead>
                <tr>
                    <th>File Name</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($files as $file): ?>
                    <tr>
                        <td>
                            <!-- Display file icon based on file type -->
                            <?php echo getFileIcon($file); ?>
                            <?php echo htmlspecialchars($file, ENT_QUOTES, 'UTF-8'); ?>
                        </td>
                        <td>
                            <!-- Download file form -->
                            <a href="<?php echo $postDir . '/' . htmlspecialchars($file, ENT_QUOTES, 'UTF-8'); ?>" download class="download-file-button">Download</a>

                            <!-- Delete file form -->
                            <form action="edit.php?edit=<?php echo urlencode($slug); ?>" method="POST" style="display:inline;">
                                <input type="hidden" name="file_name" value="<?php echo htmlspecialchars($file, ENT_QUOTES, 'UTF-8'); ?>">
                                <button type="submit" name="delete_file" onclick="return confirm('Are you sure you want to delete this file?')" class="delete-file-button">Delete File</button>
                            </form>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>

</body>
<style>
    .container {
        max-width: 900px;
        margin: 0 auto;
        padding: 20px;
        background-color: #1c1c1c;
        border-radius: 8px;
        box-shadow: 0 4px 10px rgba(0, 0, 0, 0.2);
    }

    h1 {
        color: #e0e0e0;
        font-size: 26px;
        margin-bottom: 20px;
    }

    h2 {
        color: #e0e0e0;
        font-size: 22px;
        margin-top: 20px;
    }

    form {
        margin-bottom: 20px;
    }

    .upload-input {
        padding: 10px;
        border-radius: 5px;
        border: 1px solid #333;
        background-color: #2a2a2a;
        color: #e0e0e0;
    }

    .upload-button, .delete-button, .delete-file-button, .download-file-button {
        padding: 10px 20px;
        background-color: #d9534f;
        color: white;
        border: none;
        border-radius: 5px;
        cursor: pointer;
        font-size: 14px;
        transition: background-color 0.3s ease;
    }

    .upload-button:hover, .delete-button:hover, .delete-file-button:hover, .download-file-button:hover {
        background-color: #c82333;
    }

    .download-file-button {
        background-color: #5bc0de;
        margin-right: 10px;
    }

    table {
        width: 100%;
        margin-top: 20px;
        border-collapse: collapse;
    }

    th, td {
        padding: 12px;
        text-align: left;
        border: 1px solid #333;
        color: #e0e0e0;
    }

    th {
        background-color: #1a1a1a;
    }

    tr:nth-child(even) {
        background-color: #252525;
    }

    tr:nth-child(odd) {
        background-color: #1e1e1e;
    }

    td form {
        display: inline;
    }

    .message {
        font-size: 16px;
        margin-top: 10px;
        padding: 10px;
        border-radius: 5px;
    }

    .success {
        background-color: #179317;
        color: white;
    }

    .error {
        background-color: #d9534f;
        color: white;
    }
</style>
</html>
