<?php
// Set SEO title and description for the numbers page
$seoTitle = "List of Brands Logos with Numbers";
$metaDescription = "Explore a collection of brand logos that include numbers. Download logos in various formats like PNG, SVG, and AI.";
$metaKeywords = "brand logos, logos with numbers, number logos, PNG logos, SVG logos, AI logos";

// Sanitize output to prevent XSS attacks
$seoTitle = htmlspecialchars($seoTitle, ENT_QUOTES, 'UTF-8');
$metaDescription = htmlspecialchars($metaDescription, ENT_QUOTES, 'UTF-8');
$metaKeywords = htmlspecialchars($metaKeywords, ENT_QUOTES, 'UTF-8');

// Pagination setup
$logosPerPage = 24; // Number of logos per page
$currentPage = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$currentPage = max(1, $currentPage); // Ensure the current page is at least 1

// Logo directory path
$baseDir = __DIR__ . '/logos'; // Adjust the server path if necessary
$webBaseUrl = '/logos'; // Web-accessible URL

// Get all folders in the logos directory
$folders = array_filter(glob($baseDir . '/*'), 'is_dir');

// Filter logos that contain numbers in the brand name (i.e., folder name)
$filteredLogos = array_filter($folders, function($folder) {
    return preg_match('/\d/', basename($folder)); // Check if the folder name contains a number
});

// Pagination setup for the filtered logos
$totalLogos = count($filteredLogos);
$totalPages = ceil($totalLogos / $logosPerPage);

// Determine the starting index for the current page
$startIndex = ($currentPage - 1) * $logosPerPage;

// Slice the filtered logos for the current page
$currentLogos = array_slice($filteredLogos, $startIndex, $logosPerPage);

// Dynamic description for SEO and readability
$seoDescription = "We have $totalLogos brand logos with numbers for you. ";
$seoDescription .= "Find high-quality logos containing numbers available for download in PNG, SVG, and AI formats.";
$seoDescription = htmlspecialchars($seoDescription, ENT_QUOTES, 'UTF-8'); // Sanitize description

// Include header.php for the page
include 'header.php'; // Ensure the header is included from the root or the correct folder
?>

<!-- Meta tags for SEO -->
<head>
    <title><?php echo $seoTitle; ?></title>
    <meta name="description" content="<?php echo $metaDescription; ?>">
    <meta name="keywords" content="<?php echo $metaKeywords; ?>">
    <meta name="robots" content="index, follow">
</head>

<link rel="stylesheet" href="/styles.css"> <!-- Assuming styles.css is in the main directory -->

<div class="container">
    <div class="centered-container">
        <h1><?php echo $seoTitle; ?></h1>

        <!-- Dynamic Description Section with h2 tag -->
        <h2 style="background-color: #f0f0f0; padding: 10px; margin-top: 5px; color: #333; font-weight: normal; font-size: 18px; line-height: 1.5;">
            <?= $seoDescription; ?>
        </h2>

        <!-- Logos Grid -->
        <div class="recent-posts">
            <div class="recent-posts-container">
                <?php
                // Check if any logos were found
                if (empty($currentLogos)) {
                    echo '<p>No logos found with numbers.</p>';
                } else {
                    // Display filtered logos for the current page
                    foreach ($currentLogos as $folder) {
                        $brand_name = basename($folder); // Get folder name as brand name
                        $pngFiles = glob($folder . '/*.png'); // Get all PNG files in the folder

                        if (!empty($pngFiles)) {
                            $thumbnail_url = $webBaseUrl . '/' . $brand_name . '/' . basename($pngFiles[0]); // Build the web URL
                            $post_slug = strtolower(trim(str_replace(' ', '-', $brand_name))); // Create slug for the post link
                            $post_link = "/logos/$post_slug/";

                            echo '<div class="recent-post">';
                            echo '<a href="' . $post_link . '">';
                            echo '<img src="' . htmlspecialchars($thumbnail_url, ENT_QUOTES, 'UTF-8') . '" alt="' . htmlspecialchars($brand_name, ENT_QUOTES, 'UTF-8') . ' Logo" class="recent-post-thumbnail">';
                            echo '<p>' . htmlspecialchars($brand_name, ENT_QUOTES, 'UTF-8') . ' Logo</p>';
                            echo '</a>';
                            echo '</div>';
                        }
                    }
                }
                ?>
            </div>
        </div>

        <!-- Pagination Controls -->
        <?php if ($totalPages > 1): ?>
        <div class="pagination-container">
            <div class="pagination">
                <span class="pagination-info">Page <?php echo $currentPage; ?> of <?php echo $totalPages; ?></span>

                <div class="pagination-links">
                    <?php if ($currentPage > 1): ?>
                    <a class="pagination-link" href="/numbers?page=<?php echo $currentPage - 1; ?>">&laquo; Previous</a>
                    <?php endif; ?>

                    <?php if ($currentPage < $totalPages): ?>
                    <a class="pagination-link" href="/numbers?page=<?php echo $currentPage + 1; ?>">Next &raquo;</a>
                    <?php endif; ?>
                </div>

                <!-- Jump to specific page input -->
                <form action="/numbers" method="get" class="pagination-form">
                    <input type="number" name="page" min="1" max="<?php echo $totalPages; ?>" placeholder="Go to page" required>
                    <button type="submit">Go</button>
                </form>
            </div>
        </div>
        <?php endif; ?>
    </div>
</div>

<?php
// Include footer.php for the page
include 'footer.php'; // Ensure footer is included correctly from the root or the correct folder
?>

<link rel="stylesheet" href="https://logoa2z.com/alphabets/styles.css"> <!-- Assuming styles.css is in the main directory -->
