<?php
// Start the session
session_start();

// Redirect to login page if not logged in
if (!isset($_SESSION['logged_in']) || $_SESSION['logged_in'] !== true) {
    header('Location: login.php'); // Redirect to login.php if not logged in
    exit;
}

// Directory to upload ZIP files
$uploadDir = $_SERVER['DOCUMENT_ROOT'] . '/logos/'; // Change this path if needed

// Initialize message variables
$uploadMessage = '';
$errorMessage = '';
$extractedFolders = 0;
$zipFiles = [];

// Get the list of .zip files in the directory
if ($handle = opendir($uploadDir)) {
    while (false !== ($entry = readdir($handle))) {
        if (pathinfo($entry, PATHINFO_EXTENSION) === 'zip') {
            $zipFiles[] = $entry; // Store zip file names
        }
    }
    closedir($handle);
}

// Handle the ZIP file upload
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_FILES['zip_upload'])) {
    $uploadFile = $_FILES['zip_upload'];

    // Check for upload errors
    if ($uploadFile['error'] === UPLOAD_ERR_OK) {
        $fileTmpPath = $uploadFile['tmp_name'];
        $fileName = basename($uploadFile['name']);
        $filePath = $uploadDir . $fileName;

        // Validate that the file is a ZIP file
        if (pathinfo($fileName, PATHINFO_EXTENSION) === 'zip') {
            // Move the uploaded file to the server
            if (move_uploaded_file($fileTmpPath, $filePath)) {
                $uploadMessage = "File '$fileName' has been uploaded successfully.";
                // Reload the page to update the file list
                header("Location: uploadzip.php");
                exit;
            } else {
                $errorMessage = "Error: File upload failed.";
            }
        } else {
            $errorMessage = "Error: Only ZIP files are allowed.";
        }
    } else {
        $errorMessage = "Error: " . $uploadFile['error'];
    }
}

// Handle the extraction of ZIP file
if (isset($_POST['extract_zip'])) {
    $zipFile = $_POST['zip_file'];

    // Validate if the file is a ZIP
    if (pathinfo($zipFile, PATHINFO_EXTENSION) === 'zip') {
        $zip = new ZipArchive();
        $zipPath = $uploadDir . $zipFile;

        // Open the ZIP file
        if ($zip->open($zipPath) === TRUE) {
            // Create a directory to extract the files
            $extractDir = $uploadDir . pathinfo($zipFile, PATHINFO_FILENAME) . '/';
            mkdir($extractDir);

            // Extract the ZIP contents
            if ($zip->extractTo($extractDir)) {
                $zip->close();
                $uploadMessage = "The ZIP file '$zipFile' has been extracted successfully.";
                
                // Count the number of folders extracted
                $folders = glob($extractDir . '*', GLOB_ONLYDIR);
                $extractedFolders = count($folders);
            } else {
                $errorMessage = "Error: Failed to extract the ZIP file.";
            }
        } else {
            $errorMessage = "Error: Unable to open the ZIP file.";
        }
    } else {
        $errorMessage = "Error: The file is not a valid ZIP file.";
    }
}

// Handle ZIP file deletion
if (isset($_POST['delete_zip'])) {
    $zipFile = $_POST['zip_file_to_delete'];
    $zipPath = $uploadDir . $zipFile;

    // Delete the ZIP file
    if (file_exists($zipPath)) {
        if (unlink($zipPath)) {
            $uploadMessage = "The file '$zipFile' has been deleted successfully.";
            // Reload the page to update the file list
            header("Location: uploadzip.php");
            exit;
        } else {
            $errorMessage = "Error: Unable to delete the file.";
        }
    } else {
        $errorMessage = "Error: File not found.";
    }
}

?>

<!DOCTYPE html>
<html lang="en">
    <?php include 'header.php'; ?>

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Upload ZIP - Logo2Z</title>
    <link rel="stylesheet" href="styles.css">
</head>
<body>

    <div class="container">
        <h1>Upload ZIP File</h1>

        <!-- Success or Error Message -->
        <?php if ($uploadMessage): ?>
            <div class="message success"><?php echo htmlspecialchars($uploadMessage, ENT_QUOTES, 'UTF-8'); ?></div>
        <?php endif; ?>

        <?php if ($errorMessage): ?>
            <div class="message error"><?php echo htmlspecialchars($errorMessage, ENT_QUOTES, 'UTF-8'); ?></div>
        <?php endif; ?>

        <!-- Upload ZIP Form -->
        <form action="uploadzip.php" method="POST" enctype="multipart/form-data" class="upload-form" id="uploadForm">
            <input type="file" name="zip_upload" class="upload-input" accept=".zip" required>
            <button type="submit" class="upload-button" id="uploadButton">Upload ZIP File</button>
        </form>

        <!-- List of Available ZIP Files -->
        <h2>Available ZIP Files</h2>
        <?php if (count($zipFiles) > 0): ?>
            <ul class="zip-file-list">
                <?php foreach ($zipFiles as $zipFile): 
                    $filePath = $uploadDir . $zipFile;
                    $fileSize = filesize($filePath);
                    ?>
                    <li>
                        <?php echo htmlspecialchars($zipFile, ENT_QUOTES, 'UTF-8'); ?> 
                        (<?php echo formatBytes($fileSize); ?>)

                        <!-- Extract Button -->
                        <form action="uploadzip.php" method="POST" style="display:inline;">
                            <input type="hidden" name="zip_file" value="<?php echo htmlspecialchars($zipFile, ENT_QUOTES, 'UTF-8'); ?>">
                            <button type="submit" name="extract_zip" class="extract-button">Extract</button>
                        </form>

                        <!-- Delete Button -->
                        <form action="uploadzip.php" method="POST" style="display:inline;">
                            <input type="hidden" name="zip_file_to_delete" value="<?php echo htmlspecialchars($zipFile, ENT_QUOTES, 'UTF-8'); ?>">
                            <button type="submit" name="delete_zip" class="delete-button">Delete</button>
                        </form>
                    </li>
                <?php endforeach; ?>
            </ul>
        <?php else: ?>
            <p>No ZIP files found.</p>
        <?php endif; ?>

        <!-- Show the number of extracted folders -->
        <?php if ($extractedFolders > 0): ?>
            <div class="message success">
                <?php echo "Extraction completed. $extractedFolders folder(s) were extracted."; ?>
            </div>
        <?php endif; ?>

        <!-- Upload Progress Bar (Handled by JS) -->
        <div id="progressBarContainer" style="display:none;">
            <progress id="uploadProgress" value="0" max="100" style="width:100%; height: 25px; background-color: #f3f3f3;"></progress>
        </div>
    </div>

</body>

<script>
    // Handle file upload progress
    const form = document.getElementById('uploadForm');
    const progressBarContainer = document.getElementById('progressBarContainer');
    const uploadProgress = document.getElementById('uploadProgress');
    const uploadButton = document.getElementById('uploadButton');

    form.addEventListener('submit', function(event) {
        event.preventDefault(); // Prevent the default form submission
        uploadButton.disabled = true; // Disable the upload button
        progressBarContainer.style.display = 'block'; // Show progress bar

        const formData = new FormData(form);
        const xhr = new XMLHttpRequest();
        xhr.open('POST', 'uploadzip.php', true);

        // Update progress bar during upload
        xhr.upload.onprogress = function(event) {
            if (event.lengthComputable) {
                const percentComplete = (event.loaded / event.total) * 100;
                uploadProgress.value = percentComplete;
                uploadProgress.style.backgroundColor = 'limegreen'; // Change progress bar color
            }
        };

        // After upload is complete, reset and show success
        xhr.onload = function() {
            if (xhr.status === 200) {
                // If upload is successful, hide the progress bar
                uploadProgress.value = 100; // Complete the progress bar
                setTimeout(function() {
                    progressBarContainer.style.display = 'none'; // Hide progress bar
                }, 1000);
                // Reload the page to show the extract button
                location.reload();
            } else {
                alert('Error: ' + xhr.statusText);
            }
        };

        // Send the form data (ZIP file)
        xhr.send(formData);
    });
</script>

<style>
    /* The same style as edit.php */
    .container {
        max-width: 900px;
        margin: 0 auto;
        padding: 20px;
        background-color: #1c1c1c;
        border-radius: 8px;
        box-shadow: 0 4px 10px rgba(0, 0, 0, 0.2);
    }

    h1 {
        color: #e0e0e0;
        font-size: 26px;
        margin-bottom: 20px;
    }

    .upload-form {
        margin-bottom: 20px;
    }

    .upload-input {
        padding: 10px;
        border-radius: 5px;
        border: 1px solid #333;
        background-color: #2a2a2a;
        color: #e0e0e0;
    }

    .upload-button, .extract-button, .delete-button {
        padding: 10px 20px;
        background-color: #d9534f;
        color: white;
        border: none;
        border-radius: 5px;
        cursor: pointer;
        font-size: 14px;
        transition: background-color 0.3s ease;
    }

    .upload-button:hover, .extract-button:hover, .delete-button:hover {
        background-color: #c82333;
    }

    .message.success {
        color: limegreen;
        font-size: 16px;
        margin-top: 10px;
        font-weight: bold;
    }

    .message.error {
        color: #d9534f;
        font-size: 16px;
        margin-top: 10px;
        font-weight: bold;
    }

    .zip-file-list {
        list-style-type: none;
        padding-left: 0;
    }

    .zip-file-list li {
        margin-bottom: 15px;
        color: #e0e0e0;
        font-size: 14px;
    }

    #progressBarContainer {
        margin-top: 20px;
        margin-bottom: 20px;
    }
</style>

</html>

<?php
// Helper function to format file size
function formatBytes($bytes, $precision = 2) {
    $units = ['B', 'KB', 'MB', 'GB', 'TB'];
    $bytes = max($bytes, 0);
    $pow = floor(($bytes ? log($bytes) : 0) / log(1024));
    $bytes /= pow(1024, $pow);
    return round($bytes, $precision) . ' ' . $units[$pow];
}
?>
